#
# spec file for package marco
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libmarco-private
%define sover   1
%define _version 1.20
Name:           marco
Version:        1.20.3
Release:        1.1
Summary:        MATE window manager
License:        GPL-2.0-or-later
Group:          System/GUI/Other
Url:            https://mate-desktop.org/
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
# PATCH-FEATURE-OPENSUSE marco-gtk-3.20.patch -- Restore GLib 2.48 and GTK+ 3.20 support.
Patch0:         marco-gtk-3.20.patch
BuildRequires:  fdupes
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  zenity
BuildRequires:  pkgconfig(glib-2.0) >= 2.48
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libgtop-2.0)
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xcursor)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
Requires:       zenity
Recommends:     %{name}-lang
Provides:       windowmanager
# mate-window-manager was last used in openSUSE 13.1.
Provides:       mate-window-manager = %{version}
Obsoletes:      mate-window-manager < %{version}
Obsoletes:      mate-window-manager-lang < %{version}
%glib2_gsettings_schema_requires

%description
Marco is a small window manager, using GTK+ to do everything. It is
developed mainly for the MATE Desktop.

%package -n %{soname}%{sover}
Summary:        MATE window manager shared libraries
Group:          System/GUI/Other

%description -n %{soname}%{sover}
Marco is a small window manager, using GTK+ to do everything. It is
developed mainly for the MATE Desktop.

%package themes
Summary:        MATE window manager themes
# mate-window-manager-themes was last used in openSUSE 13.1.
Group:          System/GUI/Other
Provides:       mate-window-manager-themes = %{version}
Obsoletes:      mate-window-manager-themes < %{version}
BuildArch:      noarch

%description themes
Marco is a small window manager, using GTK+ to do everything. It is
developed mainly for the MATE Desktop.

%package devel
Summary:        MATE window manager development files
Group:          Development/Libraries/Other
Requires:       %{soname}%{sover} = %{version}
# mate-window-manager-devel was last used in openSUSE 13.1.
Provides:       mate-window-manager-devel = %{version}
Obsoletes:      mate-window-manager-devel < %{version}

%description devel
Marco is a small window manager, using GTK+ to do everything. It is
developed mainly for the MATE Desktop.

%lang_package

%prep
%setup -q
%patch0 -p1

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --libexecdir=%{_libexecdir}/%{name} \
  --disable-static                    \
  --disable-scrollkeeper              \
  --disable-schemas-install
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%suse_update_desktop_file %{name}
%suse_update_desktop_file %{buildroot}%{_datadir}/mate/wm-properties/%{name}-wm.desktop
%fdupes %{buildroot}%{_datadir}/themes/

%post -n %{soname}%{sover} -p /sbin/ldconfig

%postun -n %{soname}%{sover} -p /sbin/ldconfig

%if 0%{?suse_version} < 1500
%post
%desktop_database_post
%glib2_gsettings_schema_post

%postun
%desktop_database_postun
%glib2_gsettings_schema_postun
%endif

%files
%license COPYING
%doc NEWS README
%{_bindir}/%{name}*
%dir %{_datadir}/mate/
%{_datadir}/mate/wm-properties/
%{_datadir}/%{name}/
%{_datadir}/mate-control-center/keybindings/50-marco*.xml
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/help/C/
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man?/%{name}*.?%{?ext_man}

%files lang -f %{name}.lang

%files -n %{soname}%{sover}
%{_libdir}/*.so.%{sover}*
# Marco requires libmarco-private0 and mate-control-center requires
# it too; make libmarco-private0 own /usr/share/mate-control-center
# to avoid conflicts between packages.
%dir %{_datadir}/mate-control-center/
%dir %{_datadir}/mate-control-center/keybindings/

%files themes
%{_datadir}/themes/ClearlooksRe/
%{_datadir}/themes/Dopple-Left/
%{_datadir}/themes/Dopple/
%{_datadir}/themes/DustBlue/
%{_datadir}/themes/Spidey-Left/
%{_datadir}/themes/Spidey/
%{_datadir}/themes/Splint-Left/
%{_datadir}/themes/Splint/
%{_datadir}/themes/WinMe/
%{_datadir}/themes/eOS/

%files devel
%{_includedir}/%{name}-1/
%{_libdir}/*.so
%{_libdir}/pkgconfig/libmarco-private.pc

%changelog
* Sat Dec 22 2018 sor.alexei@meowr.ru
- Update to version 1.20.3:
  * Disable deprecation warnings for distcheck.
  * Update translations.
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 1.20.2:
  * Correct resize popup position on HiDPI displays.
  * Fix frame geometry to avoid stuck resize cursor.
  * Update translations.
* Wed Apr 11 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Fix cursor size on HiDPI displays.
  * Fix mismatched enums in keybinding detection for switch-panels
    and switch-panels-backward.
  * Fix move_to_center moving window between monitors.
  * Support HiDPI window decorations.
  * Update translations.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * Store a window flag when user resizes from tiled.
  * Allow tiled windows to be resized horizontally.
  * Avoid deprecated gdk_screen_get_monitor_(),
    gdk_screen_width/height(), gdk_screen_get_width() functions.
  * display: Don't use deprecated GdkDeviceManager.
  * tools: Remove marco-mag and marco-grayscaletools.
  * Force a window scale of 1 for the window manager, instead of
    using the default or user configured scale.
  * Avoid deprecated gdk_display_get_screen, gdk_screen_get_number.
  * Alt+Tab - define arrow keycode + numpad arrows.
  * Allow use of arrows while in a Alt+Tab pop up.
  * README: Fix names of GSettings keys.
  * keybindings: Remove uppercase from "current workspace".
  * Add a hotkey to rename the current workspace.
  * Fix windows not going to save_rect when restoring.
  * Allow horizontal and vertical resizing when a corner tiled.
  * Fix a window getting reset to saved_rect when untiling from a
    corner.
  * Add keybindings for corner tiling.
  * Implement simple corner tiling by mouse drag.
  * Implementation of WidthOfScreen and HeightOfScreen.
  * XFIXES regions are leaked during paint_windows.
  * Add stricter logic for running without XPresent support.
  * Make XPresent optional.
  * Remove debug output.
  * Add in some changes from xfwm4.
  * Cancel present_pending flag when erroring out.
  * XPresent extension support - first pass.
  * build: Drop unneeded pangoxft requirement.
  * A small bugfix for the move_to_X keybinds.
  * Bugfix for monitors of different sizes.
  * Restructured monitor keybinds and adjust save_rect.
  * Implement simple shortcuts to move a window to another monitor.
  * gschema: Fix typos.
  * compositor: Don't try to paint a window that is not viewable.
  * Fix wrong results in meta_window_titlebar_is_onscreen() for
    windows without a frame.
  * Add support for the Gtk3 _GTK_SHOW_WINDOW_MENU event.
  * A more elegant solution for handling new move-to-workspace
    keybinds.
  * Implement a setting to disable top tiling.
  * Implement tabpopup when moving a window to different workspace.
  * keybindings.c: Fix  abuild warning.
  * Reset tile_resized to false when fullscreening.
  * Update translations.
- Add marco-gtk-3.20.patch: Restore GLib 2.48 and GTK+ 3.20 support.
* Mon Nov  6 2017 sor.alexei@meowr.ru
- Update to version 1.18.2:
  * Fix Synthetic keybinding/button-grab window.
  * ui: Fix invalid object construction in frames.
  * Update translations.
* Thu May 11 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Fix a strange window switching foreground/background behaviour.
  * Fix come deprecations.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * Theme viewer: Fix build for GTK+3 and fix some GTK+ deprecations.
  * Add an ability to disable showing preselected window border on
    alt-tab.
  * Add an ability to ignore applications when show-desktop is
    triggered.
  * Schema: Make compositing on by default.
  * Workspaces: Switch wrapping behaviour for "classic" and
    "toroidal" modes (it was reversed somehow).
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Make distcheck use a currently selected GTK+ version.
  * Update translations.
* Sun May 22 2016 sor.alexei@meowr.ru
- Update to version 1.14.2:
  * GTK+3: Fix a typo with deprecated GtkMisc.
  * GTK+3 fixedtip: Add style class tooltip.
  * Update translations.
* Wed Apr 20 2016 sor.alexei@meowr.ru
- Update to version 1.14.1:
  * Fix a crash on showing Alt-Tab thumbnails with compositor on.
  * Update translations.
- Remove marco-1.14.0-fix-thumb-crash.patch.
* Tue Apr 12 2016 sor.alexei@meowr.ru
- Add marco-1.14.0-fix-thumb-crash.patch from upstream: fix a
  crash on showing Alt-Tab thumbnails.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Correct description of compositing-fast-alt-tab GSettings key
    (mention that it disables thumbnails).
  * GTK+3: Re-add ability to show alt-tab thumbnails when
    compositor is on.
  * Update translations.
  * Add Changelog generation.
* Sun Feb 21 2016 sor.alexei@meowr.ru
- Update to version 1.13.1:
  * Bump libmarco-private's sover for Gtk3 build.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Gtk3: Fix several deprecations.
  * Drop MateConf migration script.
  * Fix visual glitches appearing after unmaximising Chromium
    window.
* Mon Jan 11 2016 sor.alexei@meowr.ru
- Add missing XCursor, Xinerama and XRandR dependencies.
* Wed Jan  6 2016 sor.alexei@meowr.ru
- Add missing XComposite dependency.
* Sun Nov 29 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Fix animation issues that led to crashes and visual glitches.
  * Gtk3 fixes.
  * Update translations.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
- Provide "windowmanager".
* Tue Oct 27 2015 sor.alexei@meowr.ru
- Update to 1.11.1:
  * Use Alt-` for switching between windows of the same application.
  * Gtk3: Draw 1px tile border for tile preview.
  * Add manual and by-pointer window placement.
  * More improvements and bug fixes.
* Tue Oct 27 2015 sor.alexei@meowr.ru
- Update to 1.10.3:
  * Fix crash with minimise animation.
  * Fix crash with window moving in some distributions (boo#953036).
* Fri Aug 21 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Remove outdated assertion.
  * Make minimize item insensitive when window should not be
    minimized.
  * Fix crash when struts change during grab operation.
  * Fix switching of fullscreen Direct3D applications running in
    Wine.
  * Update translations.
* Fri Jun 12 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Assorted bugfixes.
- Spec cleanup.
* Wed Apr 15 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * Bugfixes release
- Remove marco-keybindings-pass-screen-name-instead-of.patch; merged
  on upstream release
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * Bugfixes release
* Mon Mar 23 2015 p.drouand@gmail.com
- Add marco-keybindings-pass-screen-name-instead-of.patch; pass screen
  name instead of number to error dialog (closes #150
  https://github.com/mate-desktop/marco/issues/150)
* Sun Nov 23 2014 p.drouand@gmail.com
- Update to version 1.9.3 (unstable)
  + Lot of GTK/GDK bug fixes
* Sat Nov 15 2014 p.drouand@gmail.com
- Add dependency on mate-dialogs as Marco starts it for freezed
  windows.
* Sat Nov 15 2014 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  + Use zenity instead of mate-dialogs
- Replace mate-dialogs build requirement with zenity
- Remove marco-1.8.2-fix-the-resizing-of-CSD-windows.patch; merged
  on current release
* Wed Oct 29 2014 p.drouand@gmail.com
- Add marco-1.8.2-fix-the-resizing-of-CSD-windows.patch; the windows
  can't be resized if builded with CSD
* Fri Oct  3 2014 p.drouand@gmail.com
- Update to version 1.8.2
  + Tell we are Metacity to avoid issues with maximized Java
    applications
  + Tell to GTK3 that marco support _GTK_FRAME_EXTENTS hint
* Sat Jul 12 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + No changelog available
* Mon Mar 10 2014 p.drouand@gmail.com
- marco requires libmarco-private0 and mate-control-center requires
  it too; make libmarco-private0 ownusr/share/mate-control-center to
  avoid conflicts between packages
* Mon Mar 10 2014 p.drouand@gmail.com
- Obsolete mate-window-manager-lang package to avoid conflicting
  with it
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + implement side-by-side tiling
  + use yelp-tools instead of mate-doc-utils
  + cut with fading the bar title when it's longer than the decoration
    bar
* Mon Feb 10 2014 p.drouand@gmail.com
- Initial release (version 1.7.0)
